@@ -154,7 +154,7 @@ fn display_line_nums(
 struct SourceDimensions {
     /// The number of characters used to display source lines. Any
     /// line that exceeds this length will be wrapped.
-    content_width: usize,
+    content_display_width: usize,
     /// The number of characters required to display line numbers on
     /// the LHS.
     lhs_line_nums_width: usize,
@@ -168,7 +168,11 @@ struct SourceDimensions {
 }
 
 impl SourceDimensions {
-    fn new(terminal_width: usize, line_nums: &[(Option<LineNumber>, Option<LineNumber>)]) -> Self {
+    fn new(
+        terminal_width: usize,
+        line_nums: &[(Option<LineNumber>, Option<LineNumber>)],
+        content_max_width: usize,
+    ) -> Self {
         let mut lhs_max_line: LineNumber = 1.into();
         let mut rhs_max_line: LineNumber = 1.into();
 
@@ -184,11 +188,30 @@ impl SourceDimensions {
         let lhs_line_nums_width = format_line_num(lhs_max_line).len();
         let rhs_line_nums_width = format_line_num(rhs_max_line).len();
 
+        // If the file lines are extremely short, treat them as if
+        // they have a line of 25 characters.
+        let content_max_width = max(content_max_width, 25);
+
+        // If the terminal is very wide, we don't want to use the full
+        // 50% for the LHS column, we end up with too much space
+        // between LHS and RHS.
+        //
+        // Instead, cap the display width based on the maximum length
+        // of lines within the file.
+        //
+        // This is a crude heuristic because it ignores which lines of
+        // the file actually get displayed, so we can still end up
+        // with some superfluous space. It also naively assumes that
+        // byte length is the same display length, which is generally
+        // OK because byte length will tend to be larger than the
+        // display length.
+        let display_width = min(terminal_width, (content_max_width + 4) * 2 + SPACER.len());
+
         assert!(
-            terminal_width > SPACER.len(),
+            display_width > SPACER.len(),
             "Terminal total width should not overflow"
         );
-        let lhs_total_width = (terminal_width - SPACER.len()) / 2;
+        let lhs_total_width = (display_width - SPACER.len()) / 2;
 
         let lhs_content_width = if lhs_line_nums_width < lhs_total_width {
             lhs_total_width - lhs_line_nums_width
@@ -201,7 +224,7 @@ impl SourceDimensions {
 
         let rhs_content_width = max(
             1,
-            terminal_width as isize
+            display_width as isize
                 - lhs_total_width as isize
                 - SPACER.len() as isize
                 - rhs_line_nums_width as isize,
@@ -213,7 +236,7 @@ impl SourceDimensions {
         let content_width = min(lhs_content_width, rhs_content_width);
 
         Self {
-            content_width,
+            content_display_width: content_width,
             lhs_line_nums_width,
             rhs_line_nums_width,
             lhs_max_line,
@@ -319,6 +342,14 @@ pub(crate) fn print(
     lhs_mps: &[MatchedPos],
     rhs_mps: &[MatchedPos],
 ) {
+    let mut content_max_width: usize = 0;
+    for line in lhs_src.lines() {
+        content_max_width = max(content_max_width, line.len());
+    }
+    for line in rhs_src.lines() {
+        content_max_width = max(content_max_width, line.len());
+    }
+
     let (lhs_colored_lines, rhs_colored_lines) = if display_options.use_color {
         (
             apply_colors(
@@ -407,8 +438,15 @@ pub(crate) fn print(
     let mut prev_lhs_line_num = None;
     let mut prev_rhs_line_num = None;
 
-    let lhs_lines = split_on_newlines(lhs_src).collect::<Vec<_>>();
-    let rhs_lines = split_on_newlines(rhs_src).collect::<Vec<_>>();
+    let mut lhs_lines = split_on_newlines(lhs_src).collect::<Vec<_>>();
+    let mut rhs_lines = split_on_newlines(rhs_src).collect::<Vec<_>>();
+
+    if lhs_lines.last() == Some(&"") && lhs_lines.len() > 1 {
+        lhs_lines.pop();
+    }
+    if rhs_lines.last() == Some(&"") && rhs_lines.len() > 1 {
+        rhs_lines.pop();
+    }
 
     let matched_lines = all_matched_lines_filled(lhs_mps, rhs_mps, &lhs_lines, &rhs_lines);
     let mut matched_lines_to_print = &matched_lines[..];
@@ -443,7 +481,11 @@ pub(crate) fn print(
         let no_rhs_changes = hunk.novel_rhs.is_empty();
         let same_lines = aligned_lines.iter().all(|(l, r)| l == r);
 
-        let source_dims = SourceDimensions::new(display_options.terminal_width, aligned_lines);
+        let source_dims = SourceDimensions::new(
+            display_options.terminal_width,
+            aligned_lines,
+            content_max_width,
+        );
         for (lhs_line_num, rhs_line_num) in aligned_lines {
             let lhs_line_novel = highlight_as_novel(
                 *lhs_line_num,
@@ -514,17 +556,17 @@ pub(crate) fn print(
                 let lhs_line = match lhs_line_num {
                     Some(lhs_line_num) => split_and_apply(
                         lhs_lines[lhs_line_num.as_usize()],
-                        source_dims.content_width,
+                        source_dims.content_display_width,
                         display_options.tab_width,
                         lhs_highlights.get(lhs_line_num).unwrap_or(&vec![]),
                         Side::Left,
                     ),
-                    None => vec![" ".repeat(source_dims.content_width)],
+                    None => vec![" ".repeat(source_dims.content_display_width)],
                 };
                 let rhs_line = match rhs_line_num {
                     Some(rhs_line_num) => split_and_apply(
                         rhs_lines[rhs_line_num.as_usize()],
-                        source_dims.content_width,
+                        source_dims.content_display_width,
                         display_options.tab_width,
                         rhs_highlights.get(rhs_line_num).unwrap_or(&vec![]),
                         Side::Right,
@@ -537,7 +579,7 @@ pub(crate) fn print(
                     .enumerate()
                 {
                     let lhs_line =
-                        lhs_line.unwrap_or_else(|| " ".repeat(source_dims.content_width));
+                        lhs_line.unwrap_or_else(|| " ".repeat(source_dims.content_display_width));
                     let rhs_line = rhs_line.unwrap_or_else(|| "".into());
                     let lhs_num: String = if i == 0 {
                         display_lhs_line_num.clone()
@@ -609,7 +651,7 @@ mod tests {
     #[test]
     fn test_width_calculations() {
         let line_nums = [(Some(1.into()), Some(10.into()))];
-        let source_dims = SourceDimensions::new(DEFAULT_TERMINAL_WIDTH, &line_nums);
+        let source_dims = SourceDimensions::new(DEFAULT_TERMINAL_WIDTH, &line_nums, 9999);
 
         assert_eq!(source_dims.lhs_line_nums_width, 2);
         assert_eq!(source_dims.rhs_line_nums_width, 3);
@@ -623,6 +665,7 @@ mod tests {
                 (Some(0.into()), Some(0.into())),
                 (Some(1.into()), Some(1.into())),
             ],
+            9999,
         );
 
         assert_eq!(
@@ -643,6 +686,7 @@ mod tests {
                 (Some(0.into()), Some(0.into())),
                 (Some(1.into()), Some(1.into())),
             ],
+            9999,
         );
 
         assert_eq!(
